AFRL/RDE annotation helper functions (sarpy.annotation.afrl_rde)
================================================================

.. automodule:: sarpy.annotation.afrl_rde
    :members:
    :show-inheritance:
    :inherited-members:
